@@ -45,9 +45,10 @@
 #endif
 
 
-using namespace Imf;
+using namespace OPENEXR_IMF_NAMESPACE;
 using namespace std;
 
+
 namespace {
 
 void
